@@ -149,7 +149,7 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=Non
         if 'theta_axis' in recipe['setup'].keys():
             the_boss.theta_axis_name = recipe['setup']['theta_axis']
         if 'q_axis' in recipe['setup'].keys():
-            the_boss.q_axis_name = recipe['setup']['theta_axis']
+            the_boss.q_axis_name = recipe['setup']['q_axis']
         if 'transpose' in recipe['setup'].keys():
             the_boss.transpose = recipe['setup']['transpose']
             if the_boss.transpose:
